@@ -20,7 +20,6 @@
 //!
 //! - The deserializer ignores irrelevant key-value pairs in MsgPack map objects.
 //! - MsgPack map objects must not have duplicate keys.
-//! - `Option<T>` is roughly equal to declaring `T | null` in TypeScript. Deserializer interprets `nil` as `None` whatever `T` is. So `Option<Option<T>>` is the same as `Option<T>` (unless used together with `#[optional]`.)
 //!
 //! ### Structs with named fields
 //!
@@ -74,6 +73,35 @@
 //! - On serialization, the key-value pair will not be included in the result map object when the field data contains `None`.
 //! - On deserialization, the field of the result struct will be filled with `None` when the given MsgPack map object contains no corresponding key-value pair.
 //!
+//! The `#[flatten]` attribute is used to factor out a single definition of named struct into multiple ones.
+//!
+//! ```
+//! # use msgpack_schema::*;
+//! #[derive(Serialize)]
+//! struct S1 {
+//!     #[tag = 1]
+//!     x: u32,
+//! }
+//!
+//! #[derive(Serialize)]
+//! struct S2 {
+//!     #[flatten]
+//!     s1: S1,
+//!     #[tag = 2]
+//!     y: u32,
+//! }
+//!
+//! #[derive(Serialize)]
+//! struct S3 {
+//!     #[tag = 1]
+//!     x: u32,
+//!     #[tag = 2]
+//!     y: u32,
+//! }
+//!
+//! assert_eq!(serialize(S2 { s1: S1 { x: 42 }, y: 43, }), serialize(S3 { x: 42, y: 43 }));
+//! ```
+//!
 //! ### Untagged structs with named fields
 //!
 //! Structs with named fields may be attached `#[untagged]`.
@@ -398,7 +426,7 @@ use std::convert::TryFrom;
 use std::convert::TryInto;
 use std::io::{self, Write};
 use thiserror::Error;
-use value::{Bin, Ext, Int, Nil, Str};
+use value::{Bin, Ext, Int, Str};
 
 pub struct Serializer {
     w: Vec<u8>,
@@ -554,15 +582,6 @@ impl Serialize for String {
     }
 }
 
-impl<T: Serialize> Serialize for Option<T> {
-    fn serialize(&self, serializer: &mut Serializer) {
-        match self {
-            Some(v) => serializer.serialize(v),
-            None => serializer.serialize_nil(),
-        }
-    }
-}
-
 impl<T: Serialize> Serialize for [T] {
     fn serialize(&self, serializer: &mut Serializer) {
         serializer.serialize_array(self.len() as u32);
@@ -581,6 +600,12 @@ impl<T: Serialize> Serialize for Vec<T> {
     }
 }
 
+#[doc(hidden)]
+pub trait StructSerialize: Serialize {
+    fn count_fields(&self) -> u32;
+    fn serialize_fields(&self, serializer: &mut Serializer);
+}
+
 #[derive(Debug, Clone, PartialEq)]
 pub enum Token {
     Nil,
@@ -990,16 +1015,6 @@ impl Deserialize for String {
     }
 }
 
-impl<T: Deserialize> Deserialize for Option<T> {
-    fn deserialize(deserializer: &mut Deserializer) -> Result<Self, DeserializeError> {
-        if deserializer.try_deserialize::<Nil>()?.is_some() {
-            return Ok(None);
-        }
-        let v = deserializer.deserialize()?;
-        Ok(Some(v))
-    }
-}
-
 impl<T: Deserialize> Deserialize for Vec<T> {
     fn deserialize(deserializer: &mut Deserializer) -> Result<Self, DeserializeError> {
         if let Token::Array(len) = deserializer.deserialize_token()? {
